@@ -105,3 +105,29 @@ def test_fdd_take():
     # Test that only masks are supported, for now.
     with pytest.raises(AssertionError):
         B.take(fdd, np.array([1, 2]))
+
+
+def test_fdd_properties():
+    p = GP(EQ())
+
+    # Sample observations.
+    x = B.linspace(0, 5, 5)
+    y = p(x, 0.1).sample()
+
+    # Compute posterior.
+    p = p | (p(x, 0.1), y)
+
+    fdd = p(B.linspace(0, 5, 10), 0.2)
+    mean, var = fdd.mean, fdd.var
+
+    # Check `var_diag`.
+    fdd = p(B.linspace(0, 5, 10), 0.2)
+    approx(fdd.var_diag, B.diag(var))
+
+    # Check `mean_var`.
+    fdd = p(B.linspace(0, 5, 10), 0.2)
+    approx(fdd.mean_var, (mean, var))
+
+    # Check `marginals()`.
+    fdd = p(B.linspace(0, 5, 10), 0.2)
+    approx(fdd.marginals(), (B.flatten(mean), B.diag(var)))
